@@ -1,10 +1,13 @@
 #!/bin/bash
 # dictd2dic conversion script
 #
-# Usage: dictd2dic.sh foldoc
+# Usage: dictd2dic.sh mueller7
 #
+cd /usr/share/dictd
+
 if test -e $1.dict.dz; then dictunzip $1.dict.dz; fi
 if test -e $1.dict; then
+echo "Please wait..."
 touch $1.idxhead
 echo "StarDict's dict ifo file" >dictd_www.freedict.de_$1.ifo
 echo version=2.4.2 >>dictd_www.freedict.de_$1.ifo
@@ -15,8 +18,10 @@ echo idxfilesize=`stat -c %s dictd_www.freedict.de_$1.idx` >>dictd_www.freedict.
 echo bookname=$1 >>dictd_www.freedict.de_$1.ifo
 echo date=2007.01.01 >>dictd_www.freedict.de_$1.ifo
 echo sametypesequence=m >>dictd_www.freedict.de_$1.ifo
-echo "dictd_www.freedict.de_$1 created. Put the files to /usr/share/stardict/dic"
 rm $1.idxhead
+cp dictd_www.freedict.de_$1* /usr/share/stardict/dic
+echo "dictd_www.freedict.de_$1 created. The files are in /usr/share/stardict/dic"
+echo "Restart StarDict now!"
 else
-echo "Usage: dictd2dic.sh foldoc"
+echo "Usage: dictd2dic.sh mueller7"
 fi
\ No newline at end of file
